<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Vadim Galaktionov CV 12-05-2019</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="name">
        <h1>Vadim Galaktionov</h1>
        <h2 class="subtitle">Curriculum Vitae</h2>
    </div>
    <dl class="personalia">
        <dt><strong>Phone:</strong></dt>
        <dd>+31 6 46842904</dd>
        <dt><strong>Email:</strong></dt>
        <dd>vadim@galaktionov.nl</dd>
        <dt><strong>Address:</strong></dt>
        <dd>Kangoeroestraat 71, 4817GA Breda</dd>
        <dt><strong>Nationality:</strong></dt>
        <dd>Dutch</dd>
    </dl>
    <br>
    <br>
    <br>
    <br>
    <br>
    <main>
        <h2>Work Experience</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="3">
                    <h3>Cross-sector Structural Improvement Engineer & Data Engineer @ ASML</h3><br>
                    
                    <em>Semiconductor equipment manufacturing</em>
                    
                </td>
                <td class="dates">September 2018 - present</td>
            </tr>
            
            <tr>
                <td colspan="4">
                    <p>Lead developer role in team developing a Python application for parsing, analyzing and pseudonymizing photolithography fab automation logs (Django, Pandas). Development of backend microservices (Java, Spring Boot). Collaborating with architect and project lead on requirements gathering, prioritizing, planning and estimation. Focus on improving team workflow through mentoring, code reviews, pair programming and tech presentations. Redesign and implementation of application GUI. Rotating scrum master role. Deployment of application onsite at customer lithography fab.</p>
                </td>
            </tr>
            
            
            <tr>
                <td colspan="3">
                    <h3>Full-stack Software Developer @ SolarMonkey</h3><br>
                    
                    <em>B2B software for solar PV system design and forecasting</em>
                    
                </td>
                <td class="dates">August 2016 - August 2018</td>
            </tr>
            
            <tr>
                <td colspan="4">
                    <p>Development, deployment and maintenance of a fullstack application (Django + AngularJS). Integration with external CRM software through REST API and webhooks. Building solar system performance monitoring and internal analytics tools. Implementing recommendations for solar inverters based on solar system characteristics. Focus on test-driven development and devops practices.</p>
                </td>
            </tr>
            
            
            <tr>
                <td colspan="3">
                    <h3>Data Analytics Intern @ SolarMonkey</h3><br>
                    
                    <em>B2B software for solar PV system design and forecasting</em>
                    
                </td>
                <td class="dates">March 2016 - July 2016</td>
            </tr>
            
            <tr>
                <td colspan="4">
                    <p>Improving prediction accuracy of solar panel output through accounting for various losses. Risk classification of new customers using machine learning. Automating report generation and other operational processes using Python.</p>
                </td>
            </tr>
            
            
            <tr>
                <td colspan="3">
                    <h3>Sales Advisor Vodafone @ Xerox</h3><br>
                    
                    <em>Outsourced sales and customer service</em>
                    
                </td>
                <td class="dates">January 2012 - November 2013</td>
            </tr>
            
            <tr>
                <td colspan="4">
                    <p>Inbound sales, advising private and business customers on phones and cellular/internet plans. Providing customer service and resolving order issues.</p>
                </td>
            </tr>
            
            
            <tr>
                <td colspan="3">
                    <h3>Direct Sales Agent @ Hot Networkz</h3><br>
                    
                    <em>Direct sales and promotion</em>
                    
                </td>
                <td class="dates">2008 - 2010</td>
            </tr>
            
            <tr>
                <td colspan="4">
                    <p>Inbound sales, advising private and business customers on phones and cellular/internet plans. Providing customer service and resolving order issues.</p>
                </td>
            </tr>
            
            
        </table>
        <h2>Education</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="3">
                    <h3>MSc Business Information Management</h3><br>
                    <em>Erasmus University Rotterdam</em>
                </td>
                <td class="dates">September 2015 - August 2016</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Information management, consulting, data analytics and software project management. Electives in Big Data, programming and new ways of working.</p>
                </td>
            </tr>
            
            <tr>
                <td colspan="3">
                    <h3>Exchange Semester Singapore</h3><br>
                    <em>Nanyang Technological University</em>
                </td>
                <td class="dates">August 2014 - December 2014</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Business analytics, accounting information systems, entrepreneurial finance, wealth management.</p>
                </td>
            </tr>
            
            <tr>
                <td colspan="3">
                    <h3>BSc International Business Administration</h3><br>
                    <em>Tilburg University</em>
                </td>
                <td class="dates">September 2012 - August 2015</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Broad foundation in accounting, finance, marketing, economics and management, quantitative skills. Strong international focus.</p>
                </td>
            </tr>
            
            <tr>
                <td colspan="3">
                    <h3>VWO (Atheneum)</h3><br>
                    <em>Augustinianum, Eindhoven</em>
                </td>
                <td class="dates">September 2005 - August 2011</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Economics & Society profile, mathematics and physics electives.</p>
                </td>
            </tr>
            
        </table>
        <h2>Skills</h2>
        <table class="cvtable">
            <tr>
                <td>&nbsp;</td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Programming Languages</strong>
                    <p>Python 3, JavaScript ES2018, TypeScript, Java 8/11, SQL, R, Go, Clojure, Bash. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Backend Web</strong>
                    <p>Django, Django Rest Framework, Celery, Huey, Requests, BeautifulSoup, Flask, aiohttp, Spring Boot, Node.js, Express, Luminus. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Frontend Web</strong>
                    <p>HTML5, CSS3, React, Redux, Vue, Vega, AngularJS, jQuery. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Testing Frameworks</strong>
                    <p>unittest, unittest.mock, Jest, JUnit, Mockito. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Datastores</strong>
                    <p>PostgreSQL, MySQL, SQLite, Redis, MongoDB, RabbitMQ, Kafka. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>DevOps</strong>
                    <p>Linux, Docker, Docker Compose, Fabric, Ansible, DC/OS, Consul, Nomad, Terraform, Kibana. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Data Science</strong>
                    <p>Pandas, Numpy, Scikit Learn, Matplotlib, Seaborn, dplyr, data.table, forecast, ggplot, caret, psych. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Software</strong>
                    <p>Git, Unix tools, Microsoft Office, Visual Studio Code, IntelliJ, RStudio. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Miscellaneous</strong>
                    <p>Test-driven development, Scrum, GDPR compliance. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Languages</strong>
                    <p>English - fluent, Dutch - native, Russian - native, Ukranian - beginner. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Drivers Licences</strong>
                    <p>B, AM. <br><br><br></p>
                </td>
            </tr>
            
            <tr>
                <td class="description">
                    <strong>Hobbies</strong>
                    <p>Traveling, Photography, Music, Movies, Programming. <br><br><br></p>
                </td>
            </tr>
            
        </table>
        <h2>Projects</h2>
        <table class="cvtable">
            
            <tr>
                <td>
                    <h3>MSc Thesis - "On the Economic Value of Renewable Energy Cooperatives"</h3><br>
                </td>
            </tr>
            <tr>
                <td>
                    <p>Cost/benefit analysis of solar PV cooperatives through stochastic simulation and time series forecasting. Review of renewable energy topics, in particular solar PV panels, battery storage and microgrids. Data analysis in R of electricity generation and consumption time series data from hundreds of households over a 4 year period, with hourly and minute resolutions.
                        
                        <br><a href="https://github.com/vgalaktionov/MSc-Thesis-BIM---Code-Data">https://github.com/vgalaktionov/MSc-Thesis-BIM---Code-Data</a>
                        
                    </p>
                </td>
            </tr>
            
            <tr>
                <td>
                    <h3>Curatify</h3><br>
                </td>
            </tr>
            <tr>
                <td>
                    <p>A web application to improve the experience of music discovery on the Spotify streaming service. Written in full-stack Typescript. Original prototype in Clojure. Work in progress.
                        
                        <br><a href="https://github.com/vgalaktionov/curatify">https://github.com/vgalaktionov/curatify</a>
                        
                    </p>
                </td>
            </tr>
            
        </table>
        <h2>Other Activities</h2>
        <table class="cvtable">
            
            <tr>
                <td colspan="3">
                    <h3>Treasurer (board year)</h3><br>
                    <em>Magna Concordia (student fraternity), Tilburg</em>
                </td>
                <td class="dates">2015 - 2016</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Financial planning and accounting, responsibility for budget. Led legal incorporation process of the fraternity.</p>
                </td>
            </tr>
            
            <tr>
                <td colspan="3">
                    <h3>Materials Committee</h3><br>
                    <em>TSR Vidar (student rowing association), Tilburg</em>
                </td>
                <td class="dates">2015 - 2016</td>
            </tr>
            <tr>
                <td colspan="4">
                    <p>Rowing fleet maintenance and repairs.</p>
                </td>
            </tr>
            
        </table>
    </main>
</body>

</html>